@@ -8,7 +8,6 @@ from pathlib import Path
 from sys import modules as _sys_modules
 from typing import Any, Callable, List, Optional, Tuple, Type, Union
 
-
 try:
     import dataclasses
 except ImportError:
@@ -53,7 +52,7 @@ def _json_encode_default(obj: Any) -> Any:
         if dataclasses.is_dataclass(obj):
             return dataclasses.asdict(obj)
     if isinstance(obj, bytes):
-        return str(obj, encoding="utf-8")
+        return str(obj, encoding='utf-8')
     if isinstance(obj, Path):
         return str(obj)
     if isinstance(obj, datetime):
@@ -62,14 +61,14 @@ def _json_encode_default(obj: Any) -> Any:
         return obj.total_seconds()
     if isinstance(obj, Decimal):
         return str(obj)
-    if hasattr(obj, "eject"):
+    if hasattr(obj, 'eject'):
         return obj.eject()
-    if hasattr(obj, "to_dict"):
+    if hasattr(obj, 'to_dict'):
         return obj.to_dict()
-    if hasattr(obj, "dict"):
+    if hasattr(obj, 'dict'):
         return obj.dict()
 
-    raise TypeError("Cannot encode obj as JSON: {}".format(str(obj)))
+    raise TypeError('Cannot encode obj as JSON: {}'.format(str(obj)))
 
 
 class JsonLibABC(ABC):
@@ -138,7 +137,7 @@ class JSON_STDLIB(JsonLibABC):
         default: Optional[Callable[[Any], Any]] = None,
         **kwargs: Any,
     ) -> str:
-        separators = (",", ": ") if pretty else (",", ":")
+        separators = (',', ': ') if pretty else (',', ':')
         dump_str = pyjson.dumps(
             data,
             indent=2 if pretty else None,
@@ -148,7 +147,7 @@ class JSON_STDLIB(JsonLibABC):
             **kwargs,
         )
         if append_newline:
-            return f"{dump_str}\n"
+            return f'{dump_str}\n'
         return dump_str
 
     @staticmethod
@@ -196,7 +195,7 @@ class ORJSON(JsonLibABC):
             sort_keys=sort_keys,
             append_newline=append_newline,
             default=default or _json_encode_default,
-        ).decode(encoding="utf-8")
+        ).decode(encoding='utf-8')
 
     @staticmethod
     def dumpb(
@@ -257,7 +256,7 @@ class RAPIDJSON(JsonLibABC):
             )
         )
         if append_newline:
-            return f"{dump_str}\n"
+            return f'{dump_str}\n'
         return dump_str
 
     @staticmethod
@@ -287,7 +286,7 @@ class RAPIDJSON(JsonLibABC):
         return JsonLibABC.has_rapidjson()
 
 
-def pick_lib() -> "Type[JsonLibABC]":
+def pick_lib() -> 'Type[JsonLibABC]':
     if ORJSON.useable():
         return ORJSON
     if RAPIDJSON.useable():
@@ -295,29 +294,29 @@ def pick_lib() -> "Type[JsonLibABC]":
     return JSON_STDLIB
 
 
-def _import_rapidjson() -> "Type[RAPIDJSON]":
+def _import_rapidjson() -> 'Type[RAPIDJSON]':
     if RAPIDJSON.useable():
         return RAPIDJSON
     raise ImportError('rapidjson (python-rapidjson) not installed')
 
 
-def _import_orjson() -> "Type[ORJSON]":
+def _import_orjson() -> 'Type[ORJSON]':
     if ORJSON.useable():
         return ORJSON
     raise ImportError('orjson not installed')
 
 
-def _import_json_stdlib() -> "Type[JSON_STDLIB]":
+def _import_json_stdlib() -> 'Type[JSON_STDLIB]':
     return JSON_STDLIB
 
 
 def import_json(
     jsonlibs: Optional[Union[Tuple[str], List[str]]] = None
-) -> "Type[JsonLibABC]":
+) -> 'Type[JsonLibABC]':
     lib2funk = {
-        "rapidjson": _import_rapidjson,
-        "orjson": _import_orjson,
-        "json": _import_json_stdlib,
+        'rapidjson': _import_rapidjson,
+        'orjson': _import_orjson,
+        'json': _import_json_stdlib,
     }
     jsonlibs = jsonlibs or JSONLIB_DEFAULT_PREFERENCE
 
@@ -330,6 +329,70 @@ def import_json(
     return _import_json_stdlib()
 
 
+class JsonLib:
+    _jsonlib: Type[JsonLibABC]
+
+    def __init__(self, jsonlib: Optional[Type[JsonLibABC]] = None):
+        if jsonlib:
+            self._jsonlib = jsonlib
+        else:
+            self._jsonlib = import_json()
+
+    def dumps(
+        self,
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        append_newline: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
+    ) -> str:
+        return self._jsonlib.dumps(
+            data=data,
+            pretty=pretty,
+            sort_keys=sort_keys,
+            append_newline=append_newline,
+            default=default,
+            **kwargs,
+        )
+
+    def dumpb(
+        self,
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        append_newline: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
+    ) -> bytes:
+        return self._jsonlib.dumpb(
+            data=data,
+            pretty=pretty,
+            sort_keys=sort_keys,
+            append_newline=append_newline,
+            default=default,
+            **kwargs,
+        )
+
+    def loads(self, string: str, **kwargs: Any) -> Any:
+        return self._jsonlib.loads(string, **kwargs)
+
+    def use_orjson(self) -> None:
+        self._jsonlib = _import_orjson()
+
+    def use_rapidjson(self) -> None:
+        self._jsonlib = _import_rapidjson()
+
+    def use_json_stdlib(self) -> None:
+        self._jsonlib = _import_json_stdlib()
+
+    def use_json(self) -> None:
+        self.use_json_stdlib()
+
+    def which(self) -> str:
+        return self._jsonlib.lib
+
+
 JSONLIB: Type[JsonLibABC] = import_json()
 
 
